@@ -241,6 +241,7 @@ impl State {
             Architecture::X86_32(_) => elf::EM_386 as u32,
             Architecture::Arm(_) => elf::EM_ARM as u32,
             Architecture::Aarch64(_) => elf::EM_AARCH64 as u32,
+            Architecture::S390x => elf::EM_S390 as u32,
             _ => unimplemented!("unrecognized architecture"),
         }
     }
@@ -370,7 +371,7 @@ impl State {
         pid: u32,
         tid: u32,
     ) -> Result<()> {
-        let file = object::File::parse(&dbg_image).unwrap();
+        let file = object::File::parse(dbg_image).unwrap();
         let endian = if file.is_little_endian() {
             gimli::RunTimeEndian::Little
         } else {
@@ -385,8 +386,7 @@ impl State {
             }
         };
 
-        let load_section_sup = |_| Ok(borrow::Cow::Borrowed(&[][..]));
-        let dwarf_cow = gimli::Dwarf::load(&load_section, &load_section_sup)?;
+        let dwarf_cow = gimli::Dwarf::load(&load_section)?;
         let borrow_section: &dyn for<'a> Fn(
             &'a borrow::Cow<[u8]>,
         )
@@ -598,9 +598,9 @@ impl State {
                 header: RecordHeader {
                     id: RecordId::JitCodeDebugInfo as u32,
                     record_size: 0,
-                    timestamp: timestamp,
+                    timestamp,
                 },
-                address: address,
+                address,
                 count: 0,
             };
 
@@ -616,9 +616,9 @@ impl State {
                     )
                     .unwrap();
                 let filename = myfile.to_string_lossy()?;
-                let line = row.line().unwrap_or(0);
+                let line = row.line().map(|nonzero| nonzero.get()).unwrap_or(0);
                 let column = match row.column() {
-                    gimli::ColumnType::Column(column) => column,
+                    gimli::ColumnType::Column(column) => column.get(),
                     gimli::ColumnType::LeftEdge => 0,
                 };
 
